# Google book search to Pandas DataFrame

```python
$pip install a-pandas-ex-google-book-search-to-df
from a_pandas_ex_google_book_search_to_df import pd_add_google_books_search
import pandas as pd
pd_add_google_books_search()
df=pd.Q_search_for_books(search='Programming',
                      onestring=True,
                      onlyfree=True,
                      add_to_search_query="",
                      language="en",
                      timeout=15, )

                         titel                         ...                    previewLink                    
0   Global Forum on Transparency and Exchange of I...  ...  http://books.google.com.br/books?id=uiObEAAAQB...
1   Who Knew You Could Do That with RPG IV? Modern...  ...  http://books.google.com.br/books?id=FXGpDQAAQB...
2   Agile Processes in Software Engineering and Ex...  ...  http://books.google.com.br/books?id=5QNbDwAAQB...
3   Proceedings of the 4th International Conferenc...  ...  http://books.google.com.br/books?id=q2N2DwAAQB...
4   "US" Poets Foreign Poets / Noi poeți "american...  ...  http://books.google.com.br/books?id=VPw8EAAAQB...
5   Glossika How to Read These 60 Programming Term...  ...  http://books.google.com.br/books?id=LiCEDwAAQB...
6   Lecture Slides for Programming in C++ (Version...  ...  http://books.google.com.br/books?id=1rmIDwAAQB...
7                        Relativistic Electrodynamics  ...  http://books.google.com.br/books?id=bryfBgAAQB...
8   Sustainable land management and its effects on...  ...  http://books.google.com.br/books?id=0viNDwAAQB...
9   Agile Processes in Software Engineering and Ex...  ...  http://books.google.com.br/books?id=3UKXDwAAQB...
10  Optimisation-based scheduling of an avionic sy...  ...  http://books.google.com.br/books?id=cp6cDwAAQB...
11                                            Pro TBB  ...  http://books.google.com.br/books?id=BqahDwAAQB...
12  Machining—Recent Advances, Applications and Ch...  ...  http://books.google.com.br/books?id=WTarDwAAQB...
13  Agile Processes in Software Engineering and Ex...  ...  http://books.google.com.br/books?id=d1KsDwAAQB...
14                         Programming Basics with C#  ...  http://books.google.com.br/books?id=vzKyDwAAQB...
15                                Continuum Mechanics  ...  http://books.google.com.br/books?id=QdWgBgAAQB...
16  Food transfers, cash transfers, behavior chang...  ...  http://books.google.com.br/books?id=tja1DwAAQB...
17  Country gender assessment of agriculture and t...  ...  http://books.google.com.br/books?id=vH-4DwAAQB...
18    Microscale Surface Tension and Its Applications  ...  http://books.google.com.br/books?id=Afa3DwAAQB...
19  Transfers, nutrition programming, and economic...  ...  http://books.google.com.br/books?id=ai27DwAAQB...
20              Programming for Computations - Python  ...  http://books.google.com.br/books?id=oCa7DwAAQB...
21                      Programming Persistent Memory  ...  http://books.google.com.br/books?id=jHLJDwAAQB...
22  Lecture Slides for Programming in C++ (Version...  ...  http://books.google.com.br/books?id=yl3XDwAAQB...
23  Indian Computer Science (CS) & Information Tec...  ...  http://books.google.com.br/books?id=bOXUDwAAQB...
24           Mathematical Methods in Applied Sciences  ...  http://books.google.com.br/books?id=QnPWDwAAQB...
25  Linux Commands, C, C++, Java and Python Exerci...  ...  http://books.google.com.br/books?id=FVDZDwAAQB...
26  C, C++, Java, Python, PHP, JavaScript and Linu...  ...  http://books.google.com.br/books?id=xnTcDwAAQB...
27  The role of interactive radio programming in a...  ...  http://books.google.com.br/books?id=GRzdDwAAQB...
28                                  How To Code in Go  ...  http://books.google.com.br/books?id=ppzqDwAAQB...
29   New Techniques for Adaptive Program Optimization  ...  http://books.google.com.br/books?id=OFjuDwAAQB...
30      Understanding the DOM — Document Object Model  ...  http://books.google.com.br/books?id=fNQBEAAAQB...
31  Designing a Modern Skeleton Programming Framew...  ...  http://books.google.com.br/books?id=ZLgKEAAAQB...
32           How To Build a Website with CSS and HTML  ...  http://books.google.com.br/books?id=oh0JEAAAQB...
33                             How To Code in Node.js  ...  http://books.google.com.br/books?id=zMQOEAAAQB...
34             Modernizing Applications with IBM CICS  ...  http://books.google.com.br/books?id=MX0REAAAQB...
35           How I wrote a million Wikipedia articles  ...  http://books.google.com.br/books?id=nWQhEAAAQB...
36  Exercises for Programming in C++ (Version 2021...  ...  http://books.google.com.br/books?id=GDonEAAAQB...
37  Lecture Slides for Programming in C++ (Version...  ...  http://books.google.com.br/books?id=DjonEAAAQB...
38                  Undernutrition in the Philippines  ...  http://books.google.com.br/books?id=2g8uEAAAQB...
39  Country Programming Framework for the Republic...  ...  http://books.google.com.br/books?id=srJuEAAAQB...


```